==> angularjs-input-tags-4.0.0.tgz: package/README.md <==
# angularjs-input-tags 

[![GitHub release][badge-release-img]][badge-release-lnk]
[![Dependencies Status][badge-dependencies-img]][badge-dependencies-lnk]
[![Dev Dependencies Status][badge-dev-dependencies-img]][badge-dev-dependencies-lnk]
[![Travis CI Status][badge-travis-img]][badge-travis-lnk]
[![Code Climate Status][badge-code-climate-status-img]][badge-code-climate-status-lnk]
[![Code Climate Issues][badge-code-climate-issues-img]][badge-code-climate-issues-lnk]
[![License][badge-license-img]][badge-license-lnk]

AngularJS component to manage tags in input with dropdown selector with no-dependencies

### TL;DR

- Demo and docs: [site][site]
- Install with npm: `npm install angularjs-input-tags --save`
- Develop with `npm install` and `npm run serve`
- Contrib with fork, `npm install`, develop things, `npm run build` and fork request

### Specs:

Features:
- Easy AngularJS 1.5+ Component
- Multi-level dropdown selection
- Minimum CSS applied. Use your own !

Incoming-features:
- Autocomplete
- Allow / Permit unknow tags (Allow only from dropdown option)
- Display invalid tag
- Emit Actions
- Reload dropdown data-source on typing
- Customize dropdown suggestions / tag item with provided template

### Usage && Demo

**See [example page][site] for doc and demo.**

### Contrib

Start you should play with dependencies: `npm install`

Then you should be able to develop with: `npm run serve` (with hot reload)

Finally, if you want generate the dist folder: `npm run build`

That's it, you can create fork and submit your updates :)

Technical TODOs:
- create doc with dgeni
- Create tests

Resources:
- [Npm Guide](https://docs.npmjs.com/getting-started/publishing-npm-packages)

### Execute tests TODO

*Warning: Not implemented yet*

`npm test`

### LICENCE MIT

The MIT License (MIT)

Copyright (c) 2017 HeyProf!

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

[site]: https://heyprof.github.io/angularjs-input-tags/

[badge-release-img]: https://img.shields.io/github/release/heyprof/angularjs-input-tags/all.svg?style=flat-square
[badge-release-lnk]: https://github.com/heyprof/angularjs-input-tags/releases
[badge-dependencies-img]: https://img.shields.io/david/heyprof/angularjs-input-tags.svg?style=flat-square
[badge-dependencies-lnk]: https://david-dm.org/heyprof/angularjs-input-tags
[badge-dev-dependencies-img]: https://img.shields.io/david/dev/heyprof/angularjs-input-tags.svg?style=flat-square
[badge-dev-dependencies-lnk]: https://david-dm.org/heyprof/angularjs-input-tags?type=dev
[badge-travis-img]: https://img.shields.io/travis/heyprof/angularjs-input-tags.svg?style=flat-square&label=TravisCI
[badge-travis-lnk]: https://travis-ci.org/heyprof/angularjs-input-tags
[badge-code-climate-status-img]: https://img.shields.io/codeclimate/github/heyprof/angularjs-input-tags.svg?style=flat-square&label=climate
[badge-code-climate-status-lnk]: https://codeclimate.com/github/heyprof/angularjs-input-tags
[badge-code-climate-issues-img]: https://img.shields.io/codeclimate/issues/github/heyprof/angularjs-input-tags.svg?style=flat-square&label=climate&nbsp;issues
[badge-code-climate-issues-lnk]: https://codeclimate.com/github/heyprof/angularjs-input-tags/issues
[badge-license-img]: https://img.shields.io/badge/license-MIT-blue.svg?style=flat-square
[badge-license-lnk]: https://raw.githubusercontent.com/heyprof/angularjs-input-tags/master/LICENSE

==> angularjs-input-tags-4.1.0.tgz: package/README.md <==
# angularjs-input-tags 

[![GitHub release][badge-release-img]][badge-release-lnk]
[![Greenkeeper badge][badge-greenkeeper-img]][badge-greenkeeper-lnk]
[![Travis CI Status][badge-travis-img]][badge-travis-lnk]
[![Maintainability][badge-codeclimate-maintainability-img]][badge-codeclimate-maintainability-lnk]
[![Test Coverage][badge-codeclimate-coverage-img]][badge-codeclimate-coverage-lnk]
[![License][badge-license-img]][badge-license-lnk]


AngularJS component to manage tags in input with dropdown selector with no-dependencies

### TL;DR

- Demo and docs: [site][site]
- Install with npm: `npm install angularjs-input-tags --save`
- Develop with `npm install` and `npm run serve`
- Contrib with fork, `npm install`, develop things, `npm run build` and fork request

### Specs:

Features:
- Easy AngularJS 1.5+ Component
- Multi-level dropdown selection
- Minimum CSS applied. Use your own !

Incoming-features:
- Autocomplete
- Allow / Permit unknow tags (Allow only from dropdown option)
- Display invalid tag
- Emit Actions
- Reload dropdown data-source on typing
- Customize dropdown suggestions / tag item with provided template

### Usage && Demo

**See [example page][site] for doc and demo.**

### Contrib

Start you should play with dependencies: `npm install`

Then you should be able to develop with: `npm run serve` (with hot reload)

Finally, if you want generate the dist folder: `npm run build`

That's it, you can create fork and submit your updates :)

Technical TODOs:
- create doc with dgeni
- Create tests

Resources:
- [Npm Guide](https://docs.npmjs.com/getting-started/publishing-npm-packages)

### Execute tests TODO

*Warning: Not implemented yet*

`npm test`

### LICENCE MIT

The MIT License (MIT)

Copyright (c) 2017 HeyProf!

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

[site]: https://heyprof.github.io/angularjs-input-tags/

[badge-release-img]: https://img.shields.io/github/release/heyprof/angularjs-input-tags/all.svg
[badge-release-lnk]: https://github.com/heyprof/angularjs-input-tags/releases
[badge-greenkeeper-img]: https://badges.greenkeeper.io/heyprof/angularjs-input-tags.svg
[badge-greenkeeper-lnk]: https://account.greenkeeper.io/account/heyprof
[badge-travis-img]: https://img.shields.io/travis/heyprof/angularjs-input-tags.svg?label=TravisCI
[badge-travis-lnk]: https://travis-ci.org/heyprof/angularjs-input-tags
[badge-codeclimate-maintainability-img]: https://api.codeclimate.com/v1/badges/b8e2a66055de8869c139/maintainability
[badge-codeclimate-maintainability-lnk]: https://codeclimate.com/github/heyprof/angularjs-input-tags/maintainability
[badge-codeclimate-coverage-img]: https://api.codeclimate.com/v1/badges/b8e2a66055de8869c139/test_coverage
[badge-codeclimate-coverage-lnk]: https://codeclimate.com/github/heyprof/angularjs-input-tags/test_coverage
[badge-license-img]: https://img.shields.io/badge/license-MIT-blue.svg
[badge-license-lnk]: https://raw.githubusercontent.com/heyprof/angularjs-input-tags/master/LICENSE
